vfbLib.parsers.numeric.UnicodeRangesParser
==========================================

.. currentmodule:: vfbLib.parsers.numeric

.. autoclass:: UnicodeRangesParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~UnicodeRangesParser.__init__
      ~UnicodeRangesParser.parse
      ~UnicodeRangesParser.parse_hex
      ~UnicodeRangesParser.read_double
      ~UnicodeRangesParser.read_doubles
      ~UnicodeRangesParser.read_float
      ~UnicodeRangesParser.read_floats
      ~UnicodeRangesParser.read_int16
      ~UnicodeRangesParser.read_int32
      ~UnicodeRangesParser.read_int8
      ~UnicodeRangesParser.read_str
      ~UnicodeRangesParser.read_str_all
      ~UnicodeRangesParser.read_uint16
      ~UnicodeRangesParser.read_uint32
      ~UnicodeRangesParser.read_uint8
      ~UnicodeRangesParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~UnicodeRangesParser.encoding
      ~UnicodeRangesParser.master_count
      ~UnicodeRangesParser.stream
      ~UnicodeRangesParser.ttStemsH_count
      ~UnicodeRangesParser.ttStemsV_count
   
   